Struct frame::prelude::frame_system::limits::WeightsPerClass
pub struct WeightsPerClass {
pub base_extrinsic: Weight,
pub max_extrinsic: Option<Weight>,
pub max_total: Option<Weight>,
pub reserved: Option<Weight>,
}Expand description
DispatchClass-specific weight configuration.
Fields
base_extrinsic: WeightBase weight of single extrinsic of given class.
max_extrinsic: Option<Weight>Maximal weight of single extrinsic. Should NOT include base_extrinsic cost.
None indicates that this class of extrinsics doesn’t have a limit.
max_total: Option<Weight>Block maximal total weight for all extrinsics of given class.
None indicates that weight sum of this class of extrinsics is not
restricted. Use this value carefully, since it might produce heavily oversized
blocks.
In the worst case, the total weight consumed by the class is going to be:
MAX(max_total) + MAX(reserved).
reserved: Option<Weight>Block reserved allowance for all extrinsics of a particular class.
Setting to None indicates that extrinsics of that class are allowed
to go over total block weight (but at most max_total for that class).
Setting to Some(x) guarantees that at least x weight of particular class
is processed in every block.